@@ -107,6 +107,9 @@ struct _GtkSourceFileSaverPrivate
 	gpointer progress_cb_data;
 	GDestroyNotify progress_cb_notify;
 
+	/* Warning: type instances' private data are limited to a total of 64 KiB.
+	 * See the GType documentation.
+	 */
 	gchar chunk_buffer[WRITE_CHUNK_SIZE];
 	gssize chunk_bytes_read;
 	gssize chunk_bytes_written;
@@ -370,7 +373,7 @@ gtk_source_file_saver_class_init (GtkSourceFileSaverClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_LOCATION,
 					 g_param_spec_object ("location",
-							      _("Location"),
+							      "Location",
 							      "",
 							      G_TYPE_FILE,
 							      G_PARAM_READWRITE |
@@ -387,7 +390,7 @@ gtk_source_file_saver_class_init (GtkSourceFileSaverClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_ENCODING,
 					 g_param_spec_boxed ("encoding",
-							     _("Encoding"),
+							     "Encoding",
 							     "",
 							     GTK_SOURCE_TYPE_ENCODING,
 							     G_PARAM_READWRITE |
@@ -404,7 +407,7 @@ gtk_source_file_saver_class_init (GtkSourceFileSaverClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_NEWLINE_TYPE,
 					 g_param_spec_enum ("newline-type",
-					                    _("Newline type"),
+					                    "Newline type",
 							    "",
 					                    GTK_SOURCE_TYPE_NEWLINE_TYPE,
 					                    GTK_SOURCE_NEWLINE_TYPE_LF,
@@ -422,7 +425,7 @@ gtk_source_file_saver_class_init (GtkSourceFileSaverClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_COMPRESSION_TYPE,
 					 g_param_spec_enum ("compression-type",
-					                    _("Compression type"),
+					                    "Compression type",
 					                    "",
 					                    GTK_SOURCE_TYPE_COMPRESSION_TYPE,
 					                    GTK_SOURCE_COMPRESSION_TYPE_NONE,
@@ -440,7 +443,7 @@ gtk_source_file_saver_class_init (GtkSourceFileSaverClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_FLAGS,
 					 g_param_spec_flags ("flags",
-							     _("Flags"),
+							     "Flags",
 							     "",
 							     GTK_SOURCE_TYPE_FILE_SAVER_FLAGS,
 							     GTK_SOURCE_FILE_SAVER_FLAGS_NONE,
