@@ -90,11 +90,19 @@ gutter_renderer_text_begin (GtkSourceGutterRenderer      *renderer,
                             GtkTextIter                  *start,
                             GtkTextIter                  *end)
 {
-	GtkSourceGutterRendererText *text;
-
-	text = GTK_SOURCE_GUTTER_RENDERER_TEXT (renderer);
+	GtkSourceGutterRendererText *text = GTK_SOURCE_GUTTER_RENDERER_TEXT (renderer);
 
 	create_layout (text, GTK_WIDGET (gtk_source_gutter_renderer_get_view (renderer)));
+
+	if (GTK_SOURCE_GUTTER_RENDERER_CLASS (gtk_source_gutter_renderer_text_parent_class)->begin != NULL)
+	{
+		GTK_SOURCE_GUTTER_RENDERER_CLASS (gtk_source_gutter_renderer_text_parent_class)->begin (renderer,
+													cr,
+													background_area,
+													cell_area,
+													start,
+													end);
+	}
 }
 
 static void
@@ -128,7 +136,7 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
                            GtkTextIter                  *end,
                            GtkSourceGutterRendererState  state)
 {
-	GtkSourceGutterRendererText *text;
+	GtkSourceGutterRendererText *text = GTK_SOURCE_GUTTER_RENDERER_TEXT (renderer);
 	gint width;
 	gint height;
 	PangoAttrList *attr_list;
@@ -141,16 +149,17 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 	GtkStyleContext *context;
 
 	/* Chain up to draw background */
-	GTK_SOURCE_GUTTER_RENDERER_CLASS (
-		gtk_source_gutter_renderer_text_parent_class)->draw (renderer,
-		                                                     cr,
-		                                                     background_area,
-		                                                     cell_area,
-		                                                     start,
-		                                                     end,
-		                                                     state);
+	if (GTK_SOURCE_GUTTER_RENDERER_CLASS (gtk_source_gutter_renderer_text_parent_class)->draw != NULL)
+	{
+		GTK_SOURCE_GUTTER_RENDERER_CLASS (gtk_source_gutter_renderer_text_parent_class)->draw (renderer,
+												       cr,
+												       background_area,
+												       cell_area,
+												       start,
+												       end,
+												       state);
+	}
 
-	text = GTK_SOURCE_GUTTER_RENDERER_TEXT (renderer);
 	view = gtk_source_gutter_renderer_get_view (renderer);
 
 	if (text->priv->is_markup)
@@ -179,10 +188,7 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 		                        pango_attribute_copy (text->priv->fg_attr));
 	}
 
-	pango_layout_get_size (text->priv->cached_layout, &width, &height);
-
-	width /= PANGO_SCALE;
-	height /= PANGO_SCALE;
+	pango_layout_get_pixel_size (text->priv->cached_layout, &width, &height);
 
 	gtk_source_gutter_renderer_get_alignment (renderer,
 	                                          &xalign,
@@ -227,17 +233,19 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 static void
 gutter_renderer_text_end (GtkSourceGutterRenderer *renderer)
 {
-	GtkSourceGutterRendererText *text;
+	GtkSourceGutterRendererText *text = GTK_SOURCE_GUTTER_RENDERER_TEXT (renderer);
 
-	text = GTK_SOURCE_GUTTER_RENDERER_TEXT (renderer);
-
-	g_object_unref (text->priv->cached_layout);
-	text->priv->cached_layout = NULL;
+	g_clear_object (&text->priv->cached_layout);
 
 	pango_attr_list_unref (text->priv->cached_attr_list);
 	text->priv->cached_attr_list = NULL;
 
 	text->priv->fg_attr = NULL;
+
+	if (GTK_SOURCE_GUTTER_RENDERER_CLASS (gtk_source_gutter_renderer_text_parent_class)->end != NULL)
+	{
+		GTK_SOURCE_GUTTER_RENDERER_CLASS (gtk_source_gutter_renderer_text_parent_class)->end (renderer);
+	}
 }
 
 static void
@@ -248,8 +256,6 @@ measure_text (GtkSourceGutterRendererText *renderer,
               gint                        *height)
 {
 	PangoLayout *layout;
-	gint w;
-	gint h;
 	GtkSourceGutterRenderer *r;
 	GtkTextView *view;
 
@@ -271,17 +277,7 @@ measure_text (GtkSourceGutterRendererText *renderer,
 		                       -1);
 	}
 
-	pango_layout_get_size (layout, &w, &h);
-
-	if (width)
-	{
-		*width = w / PANGO_SCALE;
-	}
-
-	if (height)
-	{
-		*height = h / PANGO_SCALE;
-	}
+	pango_layout_get_pixel_size (layout, width, height);
 
 	g_object_unref (layout);
 }
@@ -398,16 +394,16 @@ gtk_source_gutter_renderer_text_class_init (GtkSourceGutterRendererTextClass *kl
 	g_object_class_install_property (object_class,
 	                                 PROP_MARKUP,
 	                                 g_param_spec_string ("markup",
-	                                                      _("Markup"),
-	                                                      _("The markup"),
+	                                                      "Markup",
+	                                                      "The markup",
 	                                                      NULL,
 	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
 	g_object_class_install_property (object_class,
 	                                 PROP_TEXT,
 	                                 g_param_spec_string ("text",
-	                                                      _("Text"),
-	                                                      _("The text"),
+	                                                      "Text",
+	                                                      "The text",
 	                                                      NULL,
 	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
